@@ -1,5 +1,5 @@
 ##***********************************************************************
-## $Id: select.R 30 2010-08-11 13:51:42Z mariotomo $
+## $Id: select.R 38 2010-08-24 13:59:29Z mariotomo $
 ##
 ## this file is part of the R library delftfews.  delftfews is free
 ## software: you can redistribute it and/or modify it under the terms
@@ -88,7 +88,7 @@ reformat.date <- function(datestring) {
 timestamp.in.range.calendar <- function(data, from, to, tz="CET") {
   ## returns whether the timestamps of a timeseries are between start and end date
 
-  dates <- format.Date(index(data), format="%02m%02d")
+  dates <- format.Date(index(data), format="%m%d")
 
   from <- reformat.date(from)
   to <- reformat.date(to)
@@ -108,18 +108,31 @@ select.percentiles <- function(input, percentiles, score.function=sum.first, ...
   ## chooses the percentiles indicated, after the `score.function` function
   ## has applied to each column.
 
-  ## how many columns
-  N <- ncol(input)
   ## call the score.function, passing it any extra parameters
   tempdata <- score.function(input, ...)
-  ## set unique names so we can find back each individual column after
-  ## ordering by score
-  names(tempdata) <- 1:N
-  ## these are the columns.  
-  columns <- as.numeric(names(sort(tempdata)[N * percentiles / 100]))
 
-  ## result has same timestamps as input, but only the chosen columns
-  result <- input[, columns]
+  ## if no valid data was provided, return no valid data!
+  if(all(is.na(tempdata))) {
+    ## return the desired amount of columns, filled with NA and
+    ## timestamped as the input.
+    columns <- seq_len(length(percentiles))
+    result <- input[, columns]
+    result[] <- NA
+  } else {
+    ## skip all columns where the score is NA
+    input <- input[, !is.na(tempdata)]
+    tempdata <- tempdata[!is.na(tempdata)]
+    ## and now count the surviving columns
+    N <- length(tempdata)
+    ## set unique names so we can find back each individual column after
+    ## ordering by score
+    names(tempdata) <- seq_len(N)
+    ## these are the columns.  
+    columns <- as.numeric(names(sort(tempdata)[N * percentiles / 100]))
+    ## result has same timestamps as input, but only the chosen
+    ## columns
+    result <- input[, columns]
+  }
   ## force result to have the same class as the input
   class(result) <- class(input)
   ## rename columns adding a trailing .percentile
